[Rt-commit] r10671 - in rt/branches/3.999-DANGEROUS: html/REST/1.0/Forms/ticket html/REST/1.0/ticket lib/RT/Interface lib/RT/Model lib/RT/ScripAction
ruz at bestpractical.com
ruz at bestpractical.com
Sat Feb 2 00:43:18 EST 2008
Author: ruz
Date: Sat Feb 2 00:43:18 2008
New Revision: 10671
Modified:
rt/branches/3.999-DANGEROUS/html/REST/1.0/Forms/ticket/comment
rt/branches/3.999-DANGEROUS/html/REST/1.0/ticket/comment
rt/branches/3.999-DANGEROUS/html/Ticket/Elements/PreviewScrips
rt/branches/3.999-DANGEROUS/lib/RT/Interface/Web.pm
rt/branches/3.999-DANGEROUS/lib/RT/Model/Ticket.pm
rt/branches/3.999-DANGEROUS/lib/RT/ScripAction/CreateTickets.pm
Log:
* convert CcMessageTo and BccMessageTo
Modified: rt/branches/3.999-DANGEROUS/html/REST/1.0/Forms/ticket/comment
==============================================================================
--- rt/branches/3.999-DANGEROUS/html/REST/1.0/Forms/ticket/comment (original)
+++ rt/branches/3.999-DANGEROUS/html/REST/1.0/Forms/ticket/comment Sat Feb 2 00:43:18 2008
@@ -139,8 +139,8 @@
my $cc = join ", ", @{ vsplit($changes{Cc}) };
my $bcc = join ", ", @{ vsplit($changes{Bcc}) };
my ($n, $s) = $ticket->$action(mime_obj => $ent,
- CcMessageTo => $cc,
- BccMessageTo => $bcc,
+ cc_message_to => $cc,
+ bcc_message_to => $bcc,
time_taken => $changes{time_worked} || 0);
$c = "# ".$s;
if ($changes{Status}) {
Modified: rt/branches/3.999-DANGEROUS/html/REST/1.0/ticket/comment
==============================================================================
--- rt/branches/3.999-DANGEROUS/html/REST/1.0/ticket/comment (original)
+++ rt/branches/3.999-DANGEROUS/html/REST/1.0/ticket/comment Sat Feb 2 00:43:18 2008
@@ -161,8 +161,8 @@
my $cc = join ", ", @{ vsplit($k->{Cc}) };
my $bcc = join ", ", @{ vsplit($k->{Bcc}) };
my ($n, $s) = $ticket->$action(mime_obj => $ent,
- CcMessageTo => $cc,
- BccMessageTo => $bcc,
+ cc_message_to => $cc,
+ bcc_message_to => $bcc,
time_taken => $k->{time_worked} || 0);
$output = $s;
if ($k->{Status}) {
Modified: rt/branches/3.999-DANGEROUS/html/Ticket/Elements/PreviewScrips
==============================================================================
--- rt/branches/3.999-DANGEROUS/html/Ticket/Elements/PreviewScrips (original)
+++ rt/branches/3.999-DANGEROUS/html/Ticket/Elements/PreviewScrips Sat Feb 2 00:43:18 2008
@@ -129,8 +129,8 @@
);
my ( $Transaction, $description, $object ) = $ticket_obj->$action(
- CcMessageTo => $ARGS{'UpdateCc'},
- BccMessageTo => $ARGS{'UpdateBcc'},
+ cc_message_to => $ARGS{'UpdateCc'},
+ bcc_message_to => $ARGS{'UpdateBcc'},
mime_obj => $Message,
time_taken => $ARGS{'UpdateTimeWorked'},
DryRun => 1
@@ -165,8 +165,8 @@
);
my ( $id, $msg, $txn ) = $ticket_obj->$action(
- CcMessageTo => $ARGS{'UpdateCc'},
- BccMessageTo => $ARGS{'UpdateBcc'},
+ cc_message_to => $ARGS{'UpdateCc'},
+ bcc_message_to => $ARGS{'UpdateBcc'},
mime_obj => $Message,
time_taken => $ARGS{'UpdateTimeWorked'},
DryRun => 1
Modified: rt/branches/3.999-DANGEROUS/lib/RT/Interface/Web.pm
==============================================================================
--- rt/branches/3.999-DANGEROUS/lib/RT/Interface/Web.pm (original)
+++ rt/branches/3.999-DANGEROUS/lib/RT/Interface/Web.pm Sat Feb 2 00:43:18 2008
@@ -569,8 +569,8 @@
my $cc = $args{ARGSRef}->{'UpdateCc'};
my %message_args = (
- CcMessageTo => $cc,
- BccMessageTo => $bcc,
+ cc_message_to => $cc,
+ bcc_message_to => $bcc,
sign => $args{ARGSRef}->{'sign'},
encrypt => $args{ARGSRef}->{'encrypt'},
mime_obj => $Message,
Modified: rt/branches/3.999-DANGEROUS/lib/RT/Model/Ticket.pm
==============================================================================
--- rt/branches/3.999-DANGEROUS/lib/RT/ScripAction/CreateTickets.pm (original)
+++ rt/branches/3.999-DANGEROUS/lib/RT/ScripAction/CreateTickets.pm Sat Feb 2 00:43:18 2008
@@ -495,7 +495,7 @@
if ( $ticketargs->{'UpdateType'} =~ /^(private|comment)$/i ) {
my ( $Transaction, $description, $object )
= $T::Tickets{$template_id}->comment(
- BccMessageTo => $ticketargs->{'Bcc'},
+ bcc_message_to => $ticketargs->{'Bcc'},
mime_obj => $ticketargs->{'mime_obj'},
time_taken => $ticketargs->{'time_worked'}
);
@@ -508,7 +508,7 @@
{
my ( $Transaction, $description, $object )
= $T::Tickets{$template_id}->correspond(
- BccMessageTo => $ticketargs->{'Bcc'},
+ bcc_message_to => $ticketargs->{'Bcc'},
mime_obj => $ticketargs->{'mime_obj'},
time_taken => $ticketargs->{'time_worked'}
);
More information about the Rt-commit
mailing list
--- rt/branches/3.999-DANGEROUS/lib/RT/Model/Ticket.pm (original)
+++ rt/branches/3.999-DANGEROUS/lib/RT/Model/Ticket.pm Sat Feb 2 00:43:18 2008
@@ -1856,7 +1856,7 @@
If mime_obj is undefined, Content will be used to build a MIME::Entity for this
commentl
-mime_obj, time_taken, CcMessageTo, BccMessageTo, Content, dry_run
+mime_obj, time_taken, cc_message_to, bcc_message_to, Content, dry_run
If dry_run is defined, this update WILL NOT BE RECORDED. Scrips will not be committed.
They will, however, be prepared and you'll be able to access them through the transaction_obj
@@ -1907,7 +1907,7 @@
Takes a hashref with the following attributes:
-mime_obj, time_taken, CcMessageTo, BccMessageTo, Content, dry_run
+mime_obj, time_taken, cc_message_to, bcc_message_to, Content, dry_run
if there's no mime_obj, Content is used to build a MIME::Entity object
@@ -1999,7 +1999,7 @@
# convert text parts into utf-8
RT::I18N::set_mime_entity_to_utf8( $args{'mime_obj'} );
# If we've been passed in CcMessageTo and BccMessageTo fields,
# add them to the mime object for passing on to the transaction handler
# The "NotifyOtherRecipients" scripAction will look for RT-Send-Cc: and
# RT-Send-Bcc: headers
@@ -1999,7 +1999,7 @@
# convert text parts into utf-8
RT::I18N::set_mime_entity_to_utf8( $args{'mime_obj'} );
- # If we've been passed in CcMessageTo and BccMessageTo fields,
+ # If we've been passed in cc_message_to and bcc_message_to fields,
# add them to the mime object for passing on to the transaction handler
# The "NotifyOtherRecipients" scripAction will look for RT-Send-Cc: and
Modified: rt/branches/3.999-DANGEROUS/lib/RT/ScripAction/CreateTickets.pm
==============================================================================